( cd usr/lib ; rm -rf libopts.so.25 )
( cd usr/lib ; ln -sf libopts.so.25.0.2 libopts.so.25 )
( cd usr/lib ; rm -rf libopts.so )
( cd usr/lib ; ln -sf libopts.so.25.0.2 libopts.so )
( cd usr/lib ; rm -rf libguileopts.so.0 )
( cd usr/lib ; ln -sf libguileopts.so.0.0.1 libguileopts.so.0 )
( cd usr/lib ; rm -rf libguileopts.so )
( cd usr/lib ; ln -sf libguileopts.so.0.0.1 libguileopts.so )
